Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2021-02-05 14:34:03 +0300
committerCampbell Barton <ideasman42@gmail.com>2021-02-05 14:34:03 +0300
commit606805d1b78e32fe007452fd75b5d8522eb43a04 (patch)
tree2394adb4c0743d014d7e3e78369f91b074a8ed29 /source/blender/blenloader/intern/readblenentry.c
parentf8cbd333d653022d3a3340d0249dd957f02e31e5 (diff)
Cleanup: use 'r_' prefix for return arguments, order last
Diffstat (limited to 'source/blender/blenloader/intern/readblenentry.c')
-rw-r--r--source/blender/blenloader/intern/readblenentry.c12
1 files changed, 7 insertions, 5 deletions
diff --git a/source/blender/blenloader/intern/readblenentry.c b/source/blender/blenloader/intern/readblenentry.c
index 237a0340552..19033ba9bf1 100644
--- a/source/blender/blenloader/intern/readblenentry.c
+++ b/source/blender/blenloader/intern/readblenentry.c
@@ -177,7 +177,9 @@ LinkNode *BLO_blendhandle_get_datablock_names(BlendHandle *bh,
* \return A BLI_linklist of BLODataBlockInfo *. The links and #BLODataBlockInfo.asset_data should
* be freed with MEM_freeN.
*/
-LinkNode *BLO_blendhandle_get_datablock_info(BlendHandle *bh, int ofblocktype, int *tot_info_items)
+LinkNode *BLO_blendhandle_get_datablock_info(BlendHandle *bh,
+ int ofblocktype,
+ int *r_tot_info_items)
{
FileData *fd = (FileData *)bh;
LinkNode *infos = NULL;
@@ -208,7 +210,7 @@ LinkNode *BLO_blendhandle_get_datablock_info(BlendHandle *bh, int ofblocktype, i
}
}
- *tot_info_items = tot;
+ *r_tot_info_items = tot;
return infos;
}
@@ -218,10 +220,10 @@ LinkNode *BLO_blendhandle_get_datablock_info(BlendHandle *bh, int ofblocktype, i
*
* \param bh: The blendhandle to access.
* \param ofblocktype: The type of names to get.
* \param tot_prev: The length of the returned list.
* \return A BLI_linklist of PreviewImage. The PreviewImage links should be freed with malloc.
*/
-LinkNode *BLO_blendhandle_get_previews(BlendHandle *bh, int ofblocktype, int *tot_prev)
+LinkNode *BLO_blendhandle_get_previews(BlendHandle *bh, int ofblocktype, int *r_tot_prev)
{
FileData *fd = (FileData *)bh;
LinkNode *previews = NULL;
@@ -302,7 +304,7 @@ LinkNode *BLO_blendhandle_get_previews(BlendHandle *bh, int ofblocktype, int *to
}
}
- *tot_prev = tot;
+ *r_tot_prev = tot;
return previews;
}
@@ -218,10 +220,10 @@ LinkNode *BLO_blendhandle_get_datablock_info(BlendHandle *bh, int ofblocktype, i
* \param bh: The blendhandle to access.
* \param ofblocktype: The type of names to get.
- * \param tot_prev: The length of the returned list.
+ * \param r_tot_prev: The length of the returned list.
* \return A BLI_linklist of PreviewImage. The PreviewImage links should be freed with malloc.
*/